@@ -3,18 +3,18 @@
 
 from __future__ import annotations
 
-import pathlib
 from dataclasses import dataclass
-from pathlib import Path
 from time import sleep as time_sleep
 from typing import Callable, Dict, List, Optional
 
 import vlc
 
+from exclock.util import get_real_sound_filename
+
 try:
     from pync import Notifier
 except Exception:
-    from util import DummyNotifier as Notifier
+    from exclock.util import DummyNotifier as Notifier
 
 DEFAULT_TITLE = "ExClock"
 
@@ -70,20 +70,6 @@ def conv_confirm_f(s: str) -> Callable:
         return confirm_dummy
 
 
-def get_real_filename(path: str) -> str:
-    path = str(Path(path).expanduser())
-
-    if Path(path).exists():
-        return path
-
-    while path.startswith("_"):
-        path = path[1:]
-
-    return str(
-        pathlib.Path(__file__).parent.absolute().joinpath("assets").joinpath("musics").joinpath(
-            path))
-
-
 @dataclass
 class Sound:
     message: str
@@ -91,7 +77,7 @@ class Sound:
     confirm_f: Callable
 
     def __post_init__(self):
-        self.sound_filename = get_real_filename(self.sound_filename)
+        self.sound_filename = get_real_sound_filename(self.sound_filename)
 
     def run(self):
         p = vlc.MediaPlayer(self.sound_filename)
@@ -172,11 +158,3 @@ class ClockTimer:
 
         return ClockTimer(
             message=json["message"], sounds=sounds, loop=json["loop"], title=json["title"])
-
-
-if __name__ == '__main__':
-    confirm_f = confirm_dummy  # noqa: E231
-    sound = Sound(message="message", sound_filename="music.mp3", confirm_f=confirm_f)
-    sound2 = Sound(message="message", sound_filename="music2.mp3", confirm_f=confirm_f)
-    clock_timer = ClockTimer("message", sounds={0: sound, 2: sound2}, loop=2, title="abc.json5")
-    clock_timer.run()
